@@ -2,12 +2,13 @@
 # -*- coding: utf-8 -*-
 
 # insert the package for universal imports.
-import os, sys, syst3m
+import os, sys
+from dev0s import *
 
 # settings.
 SOURCE_NAME = "imag3"
-SOURCE_PATH = syst3m.defaults.source_path(__file__, back=1)
-sys.path.insert(1, syst3m.defaults.source_path(SOURCE_PATH, back=1))
+SOURCE_PATH = Defaults.source_path(__file__, back=1)
+sys.path.insert(1, Defaults.source_path(SOURCE_PATH, back=1))
 
 # imports.
 from imag3.classes.config import *
@@ -15,11 +16,11 @@ from imag3.classes import utils
 from imag3.classes.image import image
 
 # the cli object class.
-class CLI(cl1.CLI):
+class CLI_(CLI.CLI):
 	def __init__(self):
 		
 		# variables.
-		cl1.CLI.__init__(self,
+		CLI.CLI.__init__(self,
 			modes={
 				"--convert /path/to/image.icns /path/to/image.png":"Convert an image file.",
 				"--replace-pixels --input-hex #000000 --output-hex #000000 --input /path/to/image.png --output /path/to/image.converted.png":"Replace a specific color for a new color.",
@@ -69,7 +70,7 @@ class CLI(cl1.CLI):
 	
 # main.
 if __name__ == "__main__":
-	cli = CLI()
+	cli = CLI_()
 	cli.start()
 
 
